"""Test PyUnit environment. This is a required call-dummy only.
"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.0'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

import unittest
if __name__ == '__main__':
    unittest.main()
    
class UseCase(unittest.TestCase):
    pass

class TestCase(unittest.TestCase):
    pass
